@@ -38,7 +38,6 @@ static CURLcode tool_ssls_easy(struct OperationConfig *config,
                                CURLSH *share, CURL **peasy)
 {
   CURLcode result = CURLE_OK;
-  struct GlobalConfig *global = config->global;
 
   *peasy = curl_easy_init();
   if(!*peasy)
@@ -46,8 +45,9 @@ static CURLcode tool_ssls_easy(struct OperationConfig *config,
 
   result = curl_easy_setopt(*peasy, CURLOPT_SHARE, share);
   if(!result && (global->tracetype != TRACE_NONE)) {
-    my_setopt(*peasy, CURLOPT_DEBUGFUNCTION, tool_debug_cb);
-    my_setopt(*peasy, CURLOPT_DEBUGDATA, config);
+    result = my_setopt_ptr(*peasy, CURLOPT_DEBUGFUNCTION, tool_debug_cb);
+    if(!result)
+      result = my_setopt_ptr(*peasy, CURLOPT_DEBUGDATA, config);
     my_setopt_long(*peasy, CURLOPT_VERBOSE, 1L);
   }
   return result;
@@ -65,12 +65,11 @@ CURLcode tool_ssls_load(struct OperationConfig *config,
   CURLcode r = CURLE_OK;
   int i, imported;
   bool error = FALSE;
-  struct GlobalConfig *global = config->global;
 
   curlx_dyn_init(&buf, MAX_SSLS_LINE);
-  fp = fopen(filename, FOPEN_READTEXT);
+  fp = curlx_fopen(filename, FOPEN_READTEXT);
   if(!fp) { /* ok if it does not exist */
-    notef(global, "SSL session file does not exist (yet?): %s", filename);
+    notef("SSL session file does not exist (yet?): %s", filename);
     goto out;
   }
 
@@ -87,14 +86,13 @@ CURLcode tool_ssls_load(struct OperationConfig *config,
 
     c = memchr(line, ':', strlen(line));
     if(!c) {
-      warnf(global, "unrecognized line %d in ssl session file %s",
-            i, filename);
+      warnf("unrecognized line %d in ssl session file %s", i, filename);
       continue;
     }
     *c = '\0';
     r = curlx_base64_decode(line, &shmac, &shmac_len);
     if(r) {
-      warnf(global, "invalid shmax base64 encoding in line %d", i);
+      warnf("invalid shmax base64 encoding in line %d", i);
       continue;
     }
     line = c + 1;
@@ -105,13 +103,13 @@ CURLcode tool_ssls_load(struct OperationConfig *config,
     }
     r = curlx_base64_decode(line, &sdata, &sdata_len);
     if(r) {
-      warnf(global, "invalid sdata base64 encoding in line %d: %s", i, line);
+      warnf("invalid sdata base64 encoding in line %d: %s", i, line);
       continue;
     }
 
     r = curl_easy_ssls_import(easy, NULL, shmac, shmac_len, sdata, sdata_len);
     if(r) {
-      warnf(global, "import of session from line %d rejected(%d)", i, r);
+      warnf("import of session from line %d rejected(%d)", i, r);
       continue;
     }
     ++imported;
@@ -125,7 +123,7 @@ out:
   if(easy)
     curl_easy_cleanup(easy);
   if(fp)
-    fclose(fp);
+    curlx_fclose(fp);
   curlx_dyn_free(&buf);
   curl_free(shmac);
   curl_free(sdata);
@@ -133,7 +131,6 @@ out:
 }
 
 struct tool_ssls_ctx {
-  struct GlobalConfig *global;
   FILE *fp;
   int exported;
 };
@@ -181,8 +178,7 @@ static CURLcode tool_ssls_exp(CURL *easy, void *userptr,
   ctx->exported++;
 out:
   if(r)
-    warnf(ctx->global, "Warning: error saving SSL session for '%s': %d",
-          session_key, r);
+    warnf("Warning: error saving SSL session for '%s': %d", session_key, r);
   curl_free(enc);
   return r;
 }
@@ -194,11 +190,10 @@ CURLcode tool_ssls_save(struct OperationConfig *config,
   CURL *easy = NULL;
   CURLcode r = CURLE_OK;
 
-  ctx.global = config->global;
   ctx.exported = 0;
-  ctx.fp = fopen(filename, FOPEN_WRITETEXT);
+  ctx.fp = curlx_fopen(filename, FOPEN_WRITETEXT);
   if(!ctx.fp) {
-    warnf(config->global, "Warning: Failed to create SSL session file %s",
+    warnf("Warning: Failed to create SSL session file %s",
           filename);
     goto out;
   }
@@ -213,6 +208,6 @@ out:
   if(easy)
     curl_easy_cleanup(easy);
   if(ctx.fp)
-    fclose(ctx.fp);
+    curlx_fclose(ctx.fp);
   return r;
 }
