@@ -42,6 +42,10 @@
 #if !defined(__clang__) && __GNUC__ >= 7
 #pragma GCC diagnostic ignored "-Wformat-overflow"
 #endif
+#if defined(__clang__) && \
+  (__clang_major__ > 3 || (__clang_major__ == 3 && __clang_minor__ >= 1))
+#pragma clang diagnostic ignored "-Wformat-non-iso"
+#endif
 #endif
 
 #define BUFSZ    256
@@ -201,7 +205,7 @@ static int test_signed_short_formatting(void)
   i++; ss_test[i].num = -0x0050 -1; ss_test[i].expected = "-81";
   i++; ss_test[i].num = -0x0005 -1; ss_test[i].expected = "-6";
 
-  i++; ss_test[i].num =  0x0000 -1; ss_test[i].expected = "-1";
+  i++; ss_test[i].num = 0x0000 -1; ss_test[i].expected = "-1";
 
   num_sshort_tests = i;
 
@@ -427,7 +431,7 @@ static int test_signed_int_formatting(void)
   i++; si_test[i].num = -0x0050 -1; si_test[i].expected = "-81";
   i++; si_test[i].num = -0x0005 -1; si_test[i].expected = "-6";
 
-  i++; si_test[i].num =  0x0000 -1; si_test[i].expected = "-1";
+  i++; si_test[i].num = 0x0000 -1; si_test[i].expected = "-1";
 
   num_sint_tests = i;
 
@@ -494,7 +498,7 @@ static int test_signed_int_formatting(void)
   i++; si_test[i].num = -0x00000050 -1; si_test[i].expected = "-81";
   i++; si_test[i].num = -0x00000005 -1; si_test[i].expected = "-6";
 
-  i++; si_test[i].num =  0x00000000 -1; si_test[i].expected = "-1";
+  i++; si_test[i].num = 0x00000000 -1; si_test[i].expected = "-1";
 
   num_sint_tests = i;
 
@@ -577,7 +581,7 @@ static int test_signed_int_formatting(void)
   i++; si_test[i].num = -0x0000000000000070 -1; si_test[i].expected = "-113";
   i++; si_test[i].num = -0x0000000000000007 -1; si_test[i].expected = "-8";
 
-  i++; si_test[i].num =  0x0000000000000000 -1; si_test[i].expected = "-1";
+  i++; si_test[i].num = 0x0000000000000000 -1; si_test[i].expected = "-1";
 
   num_sint_tests = i;
 
@@ -804,7 +808,7 @@ static int test_signed_long_formatting(void)
   i++; sl_test[i].num = -0x0050L -1L; sl_test[i].expected = "-81";
   i++; sl_test[i].num = -0x0005L -1L; sl_test[i].expected = "-6";
 
-  i++; sl_test[i].num =  0x0000L -1L; sl_test[i].expected = "-1";
+  i++; sl_test[i].num = 0x0000L -1L; sl_test[i].expected = "-1";
 
   num_slong_tests = i;
 
@@ -871,7 +875,7 @@ static int test_signed_long_formatting(void)
   i++; sl_test[i].num = -0x00000050L -1L; sl_test[i].expected = "-81";
   i++; sl_test[i].num = -0x00000005L -1L; sl_test[i].expected = "-6";
 
-  i++; sl_test[i].num =  0x00000000L -1L; sl_test[i].expected = "-1";
+  i++; sl_test[i].num = 0x00000000L -1L; sl_test[i].expected = "-1";
 
   num_slong_tests = i;
 
@@ -954,7 +958,7 @@ static int test_signed_long_formatting(void)
   i++; sl_test[i].num = -0x0000000000000070L -1L; sl_test[i].expected = "-113";
   i++; sl_test[i].num = -0x0000000000000007L -1L; sl_test[i].expected = "-8";
 
-  i++; sl_test[i].num =  0x0000000000000000L -1L; sl_test[i].expected = "-1";
+  i++; sl_test[i].num = 0x0000000000000000L -1L; sl_test[i].expected = "-1";
 
   num_slong_tests = i;
 
@@ -1070,7 +1074,7 @@ static int test_curl_off_t_formatting(void)
   i++; co_test[i].num = -0x0000000000000070 -1; co_test[i].expected = "-113";
   i++; co_test[i].num = -0x0000000000000007 -1; co_test[i].expected = "-8";
 
-  i++; co_test[i].num =  0x0000000000000000 -1; co_test[i].expected = "-1";
+  i++; co_test[i].num = 0x0000000000000000 -1; co_test[i].expected = "-1";
 
   num_cofft_tests = i;
 
@@ -1101,7 +1105,7 @@ static int test_curl_off_t_formatting(void)
   return failed;
 }
 
-static int _string_check(int linenumber, char *buf, const char *buf2)
+static int string_check_low(int linenumber, char *buf, const char *buf2)
 {
   if(strcmp(buf, buf2)) {
     /* they shouldn't differ */
@@ -1111,9 +1115,9 @@ static int _string_check(int linenumber, char *buf, const char *buf2)
   }
   return 0;
 }
-#define string_check(x,y) _string_check(__LINE__, x, y)
+#define string_check(x,y) string_check_low(__LINE__, x, y)
 
-static int _strlen_check(int linenumber, char *buf, size_t len)
+static int strlen_check_low(int linenumber, char *buf, size_t len)
 {
   size_t buflen = strlen(buf);
   if(len != buflen) {
@@ -1124,8 +1128,7 @@ static int _strlen_check(int linenumber, char *buf, size_t len)
   }
   return 0;
 }
-
-#define strlen_check(x,y) _strlen_check(__LINE__, x, y)
+#define strlen_check(x,y) strlen_check_low(__LINE__, x, y)
 
 /*
  * The output strings in this test need to have been verified with a system
